@@ -24,6 +24,7 @@
 #include "qt5-ukui-platform-theme.h"
 
 #include <QDebug>
+#include <syslog.h>
 
 #define UKUI_PLATFORMTHEME
 
@@ -36,9 +37,7 @@ class Qt5UKUIPlatformThemePlugin : public QPlatformThemePlugin
 
 public:
     virtual QPlatformTheme *create(const QString &key, const QStringList &params) {
-        qDebug()<<"platform ukui"<<key<<params;
         if (key.toLower() == "ukui") {
-            qDebug()<<"platform ukui";
             return new Qt5UKUIPlatformTheme(params);
         }
         return nullptr;
