@@ -30,6 +30,9 @@
 #include <QApplication>
 #include <QTimer>
 
+//#include <QPluginLoader>
+//#include <QIconEnginePlugin>
+
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
 #include <QFileInfo>
 #include <QIcon>
@@ -71,7 +74,6 @@ Qt5UKUIPlatformTheme::Qt5UKUIPlatformTheme(const QStringList &args)
         QApplication::setFont(m_system_font);
 
         connect(settings, &QGSettings::changed, this, [=](const QString &key){
-            qDebug()<<key<<"changed";
             if (key == "iconThemeName") {
                 QString icontheme = settings->get("icon-theme-name").toString();
                 if (icontheme == "ukui-icon-theme-default" || icontheme == "ukui")
@@ -154,7 +156,6 @@ QVariant Qt5UKUIPlatformTheme::themeHint(ThemeHint hint) const
         return QStringList()<<"ukui";
 
     case QPlatformTheme::SystemIconThemeName: {
-        qDebug()<<"request icon theme name";
         if (UKUIStyleSettings::isSchemaInstalled("org.ukui.style")) {
             if (auto settings = UKUIStyleSettings::globalInstance()) {
                 QString icontheme = settings->get("icon-theme-name").toString();
@@ -179,6 +180,21 @@ QVariant Qt5UKUIPlatformTheme::themeHint(ThemeHint hint) const
     return QPlatformTheme::themeHint(hint);
 }
 
+QIconEngine *Qt5UKUIPlatformTheme::createIconEngine(const QString &iconName) const
+{
+//    QPluginLoader l(XDG_ICON_ENGINE_PATH);
+//    if (l.instance()) {
+//        auto p = dynamic_cast<QIconEnginePlugin *>(l.instance());
+//        auto engine = p->create();
+//        return engine;
+//    } else {
+//        return QPlatformTheme::createIconEngine(iconName);
+//    }
+//    //return new XdgIconLoaderEngine(iconName);
+
+    return QPlatformTheme::createIconEngine(iconName);
+}
+
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 9, 0))
 bool Qt5UKUIPlatformTheme::usePlatformNativeDialog(DialogType type) const
 {
