@@ -67,10 +67,6 @@ GestureHelper::GestureHelper(QObject *parent) : QObject(parent)
     m_slide_type = QGestureRecognizer::registerRecognizer(m_slider);
     m_zoom_type = QGestureRecognizer::registerRecognizer(m_zoomer);
 
-    qDebug()<<"gesture helper";
-
-    qDebug()<<m_slide_type<<"ttt";
-    qDebug()<<m_zoom_type<<"sss";
 }
 
 GestureHelper::~GestureHelper()
@@ -126,6 +122,16 @@ void GestureHelper::unregisterWidget(QWidget *widget)
 bool GestureHelper::eventFilter(QObject *watched, QEvent *event)
 {
     switch (event->type()) {
+    case QEvent::ActivationChange: {
+        // do not grab inactive window's gesture.
+        auto widget = qobject_cast<QWidget *>(watched);
+        if (widget->isActiveWindow()) {
+            widget->grabGesture(Qt::TapAndHoldGesture);
+        } else {
+            widget->ungrabGesture(Qt::TapAndHoldGesture);
+        }
+        return false;
+    }
     case QEvent::TouchBegin: {
         m_is_touching = true;
         auto te = static_cast<QTouchEvent *>(event);
